/**
 ** BMPlayerGroup.java
 **
 ** Copyright (C) 1992, 1999, 2007, 2011 Mariano Alvarez Fernandez
 ** [e-mail: malfer at telefonica.net]
 **
 ** This file is part of the Parchis4A program.
 **
 ** Parchis4A is free software: you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
 ** the Free Software Foundation, either version 3 of the License, or
 ** (at your option) any later version.
 **
 ** Parchis4A is distributed in the hope that it will be useful,
 ** but WITHOUT ANY WARRANTY; without even the implied warranty of
 ** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ** GNU General Public License for more details.
 **
 ** You should have received a copy of the GNU General Public License
 ** along with Parchis4A.  If not, see <http://www.gnu.org/licenses/>.
 **
 **/

package com.fgrim.parchis4a;

import android.content.res.Resources;
import android.graphics.Bitmap;
import android.graphics.Canvas;
import android.graphics.drawable.Drawable;
import android.util.DisplayMetrics;

public class BMPlayerGroup {
	private static int dibuPersona[] = {R.drawable.persona_amarilla, R.drawable.persona_azul,
		R.drawable.persona_roja, R.drawable.persona_verde};
	private static int dibuPersonat[] = {R.drawable.personat_amarilla, R.drawable.personat_azul,
		R.drawable.personat_roja, R.drawable.personat_verde};
	private static int dibuRobot[] = {R.drawable.android_amarillo, R.drawable.android_azul,
		R.drawable.android_rojo, R.drawable.android_verde};
	private static int dibuRobott[] = {R.drawable.androidt_amarillo, R.drawable.androidt_azul,
		R.drawable.androidt_rojo, R.drawable.androidt_verde};
	private static int dibuRobotBelt[] = {R.drawable.android_c0, R.drawable.android_c1,
		R.drawable.android_c2, R.drawable.android_c3};
	
	public BMPlayerGroup() {
	}
	
	public static Bitmap GenerateQm(Resources r, boolean acercar) {
		int anchobm = 48;
		int anchoadd = acercar ? 32 : 48;
		anchobm += anchoadd * (3);
		int pos = 0;
		Bitmap bm = Bitmap.createBitmap(anchobm, 48, Bitmap.Config.ARGB_8888);
        Canvas canvas = new Canvas(bm);
		Drawable draw = r.getDrawable(R.drawable.android_qmark);
		for (int i=0; i<4; i++) {
			draw.setBounds(pos, 0, pos+48, 48);
		    draw.draw(canvas);
		    pos += anchoadd;
		}
		bm.setDensity(DisplayMetrics.DENSITY_HIGH);
		return bm;
	}

	public static Bitmap GenerateGQm(Resources r, int ind, boolean acercar) {
		int anchobm = 48;
		int anchoadd = acercar ? 32 : 48;
		anchobm += anchoadd * (3);
		Bitmap bm = Bitmap.createBitmap(anchobm, 48, Bitmap.Config.ARGB_8888);
        Canvas canvas = new Canvas(bm);
		Drawable draw = (ind == 1) ? r.getDrawable(R.drawable.qm1) : r.getDrawable(R.drawable.qm2);
    	draw.setBounds(0, 0, anchobm, 48);
	    draw.draw(canvas);
		bm.setDensity(DisplayMetrics.DENSITY_HIGH);
		return bm;
	}

	public static Bitmap Generate(Resources r, DefPartida dp, boolean acercar) {
		int anchobm = 48;
		int anchoadd = acercar ? 32 : 48;
		if (dp.num_jg > 1) anchobm += anchoadd * (dp.num_jg - 1);
		int pos = 0;
		Bitmap bm = Bitmap.createBitmap(anchobm, 48, Bitmap.Config.ARGB_8888);
        Canvas canvas = new Canvas(bm);
		for (int i=0; i<4; i++) {
			if (dp.tipo_jugador[i] == DefPartida.PERSONA) {
				Drawable draw = r.getDrawable(dibuPersona[i]);
				draw.setBounds(pos, 0, pos+48, 48);
		        draw.draw(canvas);
		        pos += anchoadd;
			} else if (dp.tipo_jugador[i] == DefPartida.MAQUINA) {
				Drawable draw = r.getDrawable(dibuRobot[i]);
				draw.setBounds(pos, 0, pos+48, 48);
		        draw.draw(canvas);
				draw = r.getDrawable(dibuRobotBelt[dp.nivel_maquina[i]]);
				draw.setBounds(pos, 0, pos+48, 48);
		        draw.draw(canvas);
		        pos += anchoadd;
			}
		}
		bm.setDensity(DisplayMetrics.DENSITY_HIGH);
		return bm;
	}

	public static Bitmap GenerateEP(Resources r, EstadoPartida ep, boolean acercar) {
		if (!ep.haTerminado()) {
			return Generate(r, ep, acercar);
		}
		int anchobm = 48;
		int anchoadd = acercar ? 32 : 48;
		if (ep.num_jg > 1) anchobm += anchoadd * (ep.num_jg - 1);
		int pos = 0;
		Bitmap bm = Bitmap.createBitmap(anchobm, 48, Bitmap.Config.ARGB_8888);
        Canvas canvas = new Canvas(bm);
        Drawable draw;
		for (int k = 0; k < 4; k++) {
			for (int i = 0; i < 4; i++) {
				if (ep.jgha_terminado[i] == k) {
					if (ep.tipo_jugador[i] == DefPartida.PERSONA) {
						draw = (k == 0) ? r.getDrawable(dibuPersonat[i]) : r.getDrawable(dibuPersona[i]);
						draw.setBounds(pos, 0, pos + 48, 48);
						draw.draw(canvas);
						pos += anchoadd;
					} else if (ep.tipo_jugador[i] == DefPartida.MAQUINA) {
						draw = (k == 0) ? r.getDrawable(dibuRobott[i]) : r.getDrawable(dibuRobot[i]);
						draw.setBounds(pos, 0, pos + 48, 48);
						draw.draw(canvas);
						draw = r.getDrawable(dibuRobotBelt[ep.nivel_maquina[i]]);
						draw.setBounds(pos, 0, pos + 48, 48);
						draw.draw(canvas);
						pos += anchoadd;
					}
				}
			}
		}
		bm.setDensity(DisplayMetrics.DENSITY_HIGH);
		return bm;
	}
}
